@@ -70,14 +70,11 @@ def parse(hub, session: "boto3.session.Session", service: str):
         ]
         get_resource_call = ""
 
+        if not resource:
+            continue
         # Get resource and describe func
-        if resource in resources:
-            r = resources[resource]
-            get_resource_call = f'resource = hub.tool.boto3.resource.create(ctx, "{clean_service}", "{r[0]}", name)'
-            other_calls.append(get_resource_call)
-            describe_function_call = "await hub.tool.boto3.resource.describe(resource)"
-            other_calls.extend(r[1])
-        else:
+        if resource not in resources:
+            # Prefer using the client first
             for func_name in hub.pop_create.aws.template.DESCRIBE_FUNCTIONS:
                 if func_name in functions:
                     describe_function_call = f"await hub.exec.boto3.client.{clean_service}.{functions[func_name]}(name)"
@@ -87,6 +84,13 @@ def parse(hub, session: "boto3.session.Session", service: str):
                     f"Cannot determine how to describe {clean_service}.{resource}: {list(functions.keys())}"
                 )
                 continue
+        else:
+            # If the client wasn't complete, try to use a resource
+            r = resources[resource]
+            get_resource_call = f'resource = hub.tool.boto3.resource.create(ctx, "{clean_service}", "{r[0]}", name)'
+            other_calls.append(get_resource_call)
+            describe_function_call = "await hub.tool.boto3.resource.describe(resource)"
+            other_calls.extend(r[1])
 
         # Get create function
         for func_name in hub.pop_create.aws.template.CREATE_FUNCTIONS:
