@@ -115,8 +115,12 @@ ABSENT_REQUEST_FORMAT = r"""
 
     {{ function.hardcoded.waiter_call }}
 
-    after = {{ function.hardcoded.describe_function_call }}
-    result["changes"] = differ.deep_diff(before, after)
+    try:
+        after = {{ function.hardcoded.describe_function_call }}
+        result["new_state"] = after
+    except Exception as e:
+        result["comment"] = str(e)
+        result["result"] = False
     return result
 """
 
