@@ -1,4 +1,5 @@
 CLI_CONFIG = {
+    "api_version": {"subcommands": ["aws"], "dyne": "pop_create"},
     "region": {
         "subcommands": ["aws"],
         "dyne": "pop_create",
@@ -9,6 +10,11 @@ CLI_CONFIG = {
     },
 }
 CONFIG = {
+    "api_version": {
+        "default": None,
+        "help": "The cloud api version to target",
+        "dyne": "pop_create",
+    },
     "region": {
         "default": "us-west-2",
         "help": "The cloud region to target",
